==> haskell-kan-extensions-5.2-36-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.2
id: kan-extensions-5.2-I3wn4zn5hhI4om6oKrHdw8
key: kan-extensions-5.2-I3wn4zn5hhI4om6oKrHdw8
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.
category: Data Structures, Monads, Comonads, Functors
abi: f63ee3482867b23dc494a02649ba5516
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda
import-dirs: /usr/lib/ghc-8.6.4/site-local/kan-extensions-5.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/kan-extensions-5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/kan-extensions-5.2
hs-libraries: HSkan-extensions-5.2-I3wn4zn5hhI4om6oKrHdw8
includes:
    kan-extensions-common.h
depends:
    adjunctions-4.4-66v9jZQlvrfLMRPevMgXwh array-0.5.3.0 base-4.12.0.0
    comonad-5.0.4-Eb0V3lKOVycBHSbbmuvoSz containers-0.6.0.1
    contravariant-1.5-6YjeCNapF4KLECQA4h7stV
    distributive-0.6-HCLPH5GMieO8gayndVlKpm
    free-5.1-1uvQfsczS3sGeFDtVPk4Uy
    invariant-0.5.1-JdVEROVreUzHJKafuo1V2p mtl-2.2.2
    profunctors-5.3-ImiQIicYUMp1RBXlJLph4o
    semigroupoids-5.3.2-Bu2F7FQ92OC5GMxlQHm35r
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.2-IT1pgM4Lod5B9rerVXsOk7
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-kan-extensions-5.2-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-kan-extensions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: kan-extensions
version: 5.2
id: kan-extensions-5.2-FNmNaMFTWtt7C3s6Qwg6Bj
key: kan-extensions-5.2-FNmNaMFTWtt7C3s6Qwg6Bj
license: BSD-3-Clause
copyright: Copyright (C) 2008-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/kan-extensions/
synopsis: Kan extensions, Kan lifts, the Yoneda lemma, and (co)density (co)monads
description:
    Kan extensions, Kan lifts, various forms of the Yoneda lemma, and (co)density (co)monads.
category: Data Structures, Monads, Comonads, Functors
abi: 60d847559ded7d3af2fa089f695422b8
exposed: True
exposed-modules:
    Control.Comonad.Density Control.Monad.Co Control.Monad.Codensity
    Data.Functor.Contravariant.Coyoneda Data.Functor.Contravariant.Day
    Data.Functor.Contravariant.Yoneda Data.Functor.Coyoneda
    Data.Functor.Day Data.Functor.Day.Curried
    Data.Functor.Invariant.Day Data.Functor.Kan.Lan
    Data.Functor.Kan.Ran Data.Functor.Yoneda
import-dirs: /usr/lib/ghc-8.6.4/site-local/kan-extensions-5.2
library-dirs: /usr/lib/ghc-8.6.4/site-local/kan-extensions-5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/kan-extensions-5.2
hs-libraries: HSkan-extensions-5.2-FNmNaMFTWtt7C3s6Qwg6Bj
includes:
    kan-extensions-common.h
depends:
    adjunctions-4.4-Hp42fKVTFRqCCk2t9tH1RT array-0.5.3.0 base-4.12.0.0
    comonad-5.0.4-8UKAvbVXEvJ8FD0FgJJhEO containers-0.6.0.1
    contravariant-1.5-6YjeCNapF4KLECQA4h7stV
    distributive-0.6-L2Z1Ut3SFoa7TwkqYDUZRe
    free-5.1-J9rGtFi0wO6FsNAYMdbQz2
    invariant-0.5.1-9lxh5BBcWy8KhJEt8kYGu7 mtl-2.2.2
    profunctors-5.3-1xy35EiLpoK41syHomeyFK
    semigroupoids-5.3.2-KRMOBDHvPKD7cVxX6A6LMY
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
haddock-interfaces: /usr/share/doc/haskell-kan-extensions/html/kan-extensions.haddock
haddock-html: /usr/share/doc/haskell-kan-extensions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
